@@ -3,13 +3,12 @@
 . $TOP/makegen/makegen.cf
 
 lib=$1
-libobj=""
-shift
+libsrc=`echo $2 | sed "s/,/ /g"`
+libobj=`echo $3 | sed "s/,/ /g"`
 
-while test $# -gt 0
+for src in $libsrc
 do
-	src=$1
-	base=`echo $1 | sed "s/\..*//"`
+	base=`echo $src | sed "s/\..*//"`
 	obj=`echo $src | sed "s/\.c\$/.o/"`
 	libobj="$libobj $obj"
 	echo	"$obj : $src"
