@@ -29,6 +29,7 @@
 #include <pwd.h>
 #include <stdlib.h>
 #include <varargs.h>
+#include <string.h>
 
 #include "common/portability.h"
 
@@ -39,10 +40,6 @@
 
 #include "common/site.h"
 
-#ifdef MINERVA_DEBUG
-#  include "common/debug.h"
-#endif
-
 #include "msql_priv.h"
 #include "errmsg.h"
 
@@ -69,7 +66,7 @@ static	m_data *tmpDataStore = NULL,
 char	msqlErrMsg[160];
 
 RETSIGTYPE	(*oldHandler)();
-
+static void msqlDebug();
 
 #define	resetError()	(void)bzero(msqlErrMsg,sizeof(msqlErrMsg))
 #define chopError()	{ char *cp; cp = msqlErrMsg+strlen(msqlErrMsg) -1; \
@@ -190,7 +187,7 @@ static void msqlDebug(va_alist)
 **		  handlers know which one to shut down.
 */
 
-static setServerSock(sock)
+static void setServerSock(sock)
 	int	sock;
 {
 	curServerSock = sock;
@@ -208,7 +205,7 @@ static setServerSock(sock)
 **	Notes	: This is used by msqlClose and the signal handlers
 */
 
-static closeServer(sock)
+static void closeServer(sock)
 	int	sock;
 {
 	msqlDebug(MOD_API,"Server socket (%d) closed\n", sock);
@@ -259,6 +256,7 @@ RETSIGTYPE pipeHandler(sig)
 	msqlDebug(MOD_API,"Hit by pipe signal\n");
 	closeServer(curServerSock);
 	signal(SIGPIPE,pipeHandler);
+	return;
 }
 
 
@@ -356,8 +354,8 @@ static m_fdata *tableToFieldList(data)
 			head = prevField = curField;
 		}
 
-		curField->field.table = (char *)strdup(curRow->data[0]);
-		curField->field.name = (char *)strdup(curRow->data[1]);
+		curField->field.table = (char *)strdup((char *)curRow->data[0]);
+		curField->field.name = (char *)strdup((char *)curRow->data[1]);
 		curField->field.type = atoi((char*)curRow->data[2]);
 		curField->field.length = atoi((char*)curRow->data[3]);
 		curField->field.flags = 0;
@@ -1011,7 +1009,7 @@ int readQueryData(sock)
 		msqlDebug(MOD_MALLOC,"Query data row - malloc @ %X of %d\n",
 			cur, sizeof(m_data));
 		(void)bzero(cur,sizeof(m_data));
-		cur->data = (u_char **)malloc(numFields * sizeof(char *));
+		cur->data = (char **)malloc(numFields * sizeof(char *));
 		(void)bzero(cur->data,numFields * sizeof(char *));
 		cur->width = numFields;
 		off = 0;
@@ -1193,8 +1191,8 @@ m_result *msqlListFields(sock,table)
 	tmp->queryData = NULL;
 	tmp->cursor = NULL;
 	tmp->numRows = 0;
-	tmpDataStore = NULL;
 	freeQueryData(tmpDataStore);
+	tmpDataStore = NULL;
 	return(tmp);
 }
 
