@@ -68,6 +68,8 @@ int	curSock,
 	UNIXsock,
 	numCons;
 
+char	*unixPort;
+
 #define MAX_SOCK_NUM	100
 
 cinfo_t	conArray[MAX_SOCK_NUM];
@@ -103,7 +105,7 @@ void sigTrap(sig)
 #ifdef HAVE_SYS_UN_H
 	shutdown(UNIXsock,2);
 	close(UNIXsock);
-	unlink(MSQL_UNIX_ADDR);
+	unlink(unixPort);
 #endif
 	printf("\n");
 	abort();
@@ -149,8 +151,7 @@ initServer()
 		addrLen;
 	struct	sockaddr_in	IPaddr;
 	struct	servent		*serv_ptr;
-	char	*unixPort,
-		*envVar;
+	char	*envVar;
 
 #ifdef HAVE_SYS_UN_H
 	struct	sockaddr_un	UNIXaddr;
@@ -249,7 +250,7 @@ RETSIGTYPE puntServer(sig)
 #ifdef HAVE_SYS_UN_H
 	shutdown(UNIXsock,2);
 	close(UNIXsock);
-	unlink(MSQL_UNIX_ADDR);
+	unlink(unixPort);
 #endif
 	printf("\n");
 	dropCache();
@@ -344,6 +345,9 @@ setupSignals()
 #ifdef SIGTERM
 	signal(SIGTERM,puntServer);
 #endif
+#ifdef SIGHUP
+	signal(SIGHUP,SIG_IGN);
+#endif
 }
 
 
